api.system.components.code.v1.test_helpers.vacuum package — Argus-Toolbelt 1.0 documentation

# api.system.components.code.v1.test_helpers.vacuum package

## Submodules

## api.system.components.code.v1.test_helpers.vacuum.vacuum module

`api.system.components.code.v1.test_helpers.vacuum.vacuum.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/vacuum, respond with HTTP 403

`api.system.components.code.v1.test_helpers.vacuum.vacuum.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/vacuum, respond with HTTP 404

`api.system.components.code.v1.test_helpers.vacuum.vacuum.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/vacuum, respond with HTTP 200

`api.system.components.code.v1.test_helpers.vacuum.vacuum.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/system/components/code/v1/vacuum, respond with HTTP 401

## Module contents